@@ -374,11 +374,14 @@ nsSMILAnimationController::DoSample(bool aSkipUnchangedContainers)
   // Create the compositor table
   nsAutoPtr<nsSMILCompositorTable>
     currentCompositorTable(new nsSMILCompositorTable(0));
+  nsTArray<RefPtr<SVGAnimationElement>>
+    animElems(mAnimationElementTable.Count());
 
   for (auto iter = mAnimationElementTable.Iter(); !iter.Done(); iter.Next()) {
     SVGAnimationElement* animElem = iter.Get()->GetKey();
     SampleTimedElement(animElem, &activeContainers);
     AddAnimationToCompositorTable(animElem, currentCompositorTable);
+    animElems.AppendElement(animElem);
   }
   activeContainers.Clear();
 
@@ -422,7 +425,7 @@ nsSMILAnimationController::DoSample(bool aSkipUnchangedContainers)
   }
 
   nsCOMPtr<nsIDocument> kungFuDeathGrip(mDocument);  // keeps 'this' alive too
-  mDocument->FlushPendingNotifications(Flush_Style);
+  kungFuDeathGrip->FlushPendingNotifications(Flush_Style);
 
   // WARNING: 
   // WARNING: the above flush may have destroyed the pres shell and/or
