@@ -229,10 +229,11 @@ nsICOEncoder::StartImageEncode(uint32_t aWidth,
   }
 
   // parse and check any provided output options
-  uint32_t bpp = 24;
+  uint16_t bpp = 24;
   bool usePNG = true;
-  nsresult rv = ParseOptions(aOutputOptions, &bpp, &usePNG);
+  nsresult rv = ParseOptions(aOutputOptions, bpp, usePNG);
   NS_ENSURE_SUCCESS(rv, rv);
+  MOZ_ASSERT(bpp <= 32);
 
   mUsePNG = usePNG;
 
@@ -266,17 +267,13 @@ nsICOEncoder::EndImageEncode()
 // Parses the encoder options and sets the bits per pixel to use and PNG or BMP
 // See InitFromData for a description of the parse options
 nsresult
-nsICOEncoder::ParseOptions(const nsAString& aOptions, uint32_t* bpp,
-                           bool* usePNG)
+nsICOEncoder::ParseOptions(const nsAString& aOptions, uint16_t& aBppOut,
+                           bool& aUsePNGOut)
 {
   // If no parsing options just use the default of 24BPP and PNG yes
   if (aOptions.Length() == 0) {
-    if (usePNG) {
-      *usePNG = true;
-    }
-    if (bpp) {
-      *bpp = 24;
-    }
+    aUsePNGOut = true;
+    aBppOut = 24;
   }
 
   // Parse the input string into a set of name/value pairs.
@@ -304,11 +301,11 @@ nsICOEncoder::ParseOptions(const nsAString& aOptions, uint32_t* bpp,
                                 nsCaseInsensitiveCStringComparator())) {
       if (nameValuePair[1].Equals("png",
                                   nsCaseInsensitiveCStringComparator())) {
-        *usePNG = true;
+        aUsePNGOut = true;
       }
       else if (nameValuePair[1].Equals("bmp",
                                        nsCaseInsensitiveCStringComparator())) {
-        *usePNG = false;
+        aUsePNGOut = false;
       }
       else {
         return NS_ERROR_INVALID_ARG;
@@ -318,10 +315,10 @@ nsICOEncoder::ParseOptions(const nsAString& aOptions, uint32_t* bpp,
     // Parse the bpp portion of the string format=<png|bmp>;bpp=<bpp_value>
     if (nameValuePair[0].Equals("bpp", nsCaseInsensitiveCStringComparator())) {
       if (nameValuePair[1].EqualsLiteral("24")) {
-        *bpp = 24;
+        aBppOut = 24;
       }
       else if (nameValuePair[1].EqualsLiteral("32")) {
-        *bpp = 32;
+        aBppOut = 32;
       }
       else {
         return NS_ERROR_INVALID_ARG;
@@ -474,7 +471,7 @@ nsICOEncoder::InitFileHeader()
 
 // Initializes the icon directory info header mICODirEntry
 void
-nsICOEncoder::InitInfoHeader(uint32_t aBPP, uint8_t aWidth, uint8_t aHeight)
+nsICOEncoder::InitInfoHeader(uint16_t aBPP, uint8_t aWidth, uint8_t aHeight)
 {
   memset(&mICODirEntry, 0, sizeof(mICODirEntry));
   mICODirEntry.mBitCount = aBPP;
